## Governance

We identify three aspects of governence: Executive, Legislative, and Judicial. Executive governance is focused on the present, day to day operations of a DAO. Legislative governance is focused on the future, and deals with the process of making changes to the operations of a DAO. Judicial governance is focused on the past, providing an opportunity for a DAO to review and reinterpret past actions.

### Core Contracts

The key insight of [On-Chain Governance of Decentralized Autonomous Organizations (Craig Calcaterra, 2018)](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3188374) is to use Reputation as the primary incentive mechanism for DAO members, rather than relying on fungible currency alone as the representation of a DAO member's power.

Validation Pools mint and award Reputation (REP). REP can be used for staking for/against Validation Pools or staking availability to perform work, and entitles the holder to a share of DAO revenues in proportion to their REP balance. 

#### Reputation

1. Reputation (REP) is an ERC20 token 

1. Reputation internal methods (`mint`, `burn`, `update`) may be called only by the Validation Pool contract.

1. `transfer` and `transferFrom` are disabled, so that REP may not be transferred.

#### Validation Pool

1. Anyone may initiate a Validation Pool

    1. A Validation Pool may be initated with a fee

        1. Reputation (REP) is minted in proportion to the submitted fee

    1. A Validation Pool must include the following parameters

        1. Quorum (between 0 and 1)

        1. Win ratio (between 0 and 1)

        1. Binding percent (between 0 and 100%)

        1. Redistribute losing stakes (boolean)

        1. Target Forum Post (explained in the Judicial governance section)

1. A DAO member may stake Reputation for or against a Validation Pool after the pool is initiated and before the duration elapses


### Executive

The day to day operations of a DAO are centered around Work Smart Contracts (WSC) and Validation Pools (VPs). Customers request work; the work is assigned to an available worker; the worker submits Work Evidence (WEV); and the Work Evidence is validated by the rest of the DAO in a Validation Pool.

#### Work Smart Contract

1. A Worker must be able to stake availability toward a Work Contract (WSC), specifying the duration of their availability window.

1. A Customer must be able to submit a request for work to the WSC, including a fee and any necessary request details.

1. The assigned Worker must be able to submit a Work Evidence Post to the WSC, providing any necessary supporting information to verify that the work was performed correctly.

1. The Customer must be able to submit approval/disapproval of the work to the WSC.

1. The Staking Clients must be able to verify the work evidence, and stake for/against a Validation Pool targeting the Work Evidence Post.

    1. If the Validation Pool is accepted, the Worker as well as Staking Clients who staked in favor of the VP, shall receive REP rewards in proportion to their stakes.

    1. If the Validation Pool is rejected, the Worker as well as Staking Clients who staked in favor of the VP, shall have their staked REP redistributed to the Staking Clients who staked against the VP.

1. After the Validation Pool concludes, the fee provided by the Customer shall be distributed among all DAO members (Workers) in proportion to their REP balance.

### Legislative

The DAO will need to be able to update the rules by which it operates, in order to respond to changing circumstances or goals. There will not always be unanimous consensus regarding what changes to make. Therefore, we need a legislative governance process that a DAO can use in order to progress from disagreement to agreement.

To achieve such a process, we introduce a Proposal mechanism. The proposal must first reach a certain level of Attestation; then it must progress through a series of Referenda. If all Referenda are accepted, then the Proposal is accepted; otherwise the Proposal is rejected.

#### Proposals

1. Anyone may submit a Proposal

    1. Note that, if desired, this requirement could be strengthened such that only a DAO member may submit a Proposal

1. A DAO member may attest a certain amount of REP to indicate that they are aware of the proposal. The amount must be less than or equal to the DAO member's REP balance.

1. Once the Proposal has reached 10% Attestation, meaning that 10% of the DAO's total supply of REP has been attested, the first Referendum shall be initiated. This referendum should be a Validation Pool that is 0% binding, with a quorum of 1/10 and a win ratio of 2/3.

    1. If the Referendum does not meet quorum, then the Proposal is failed.

    1. If the Referendum is rejected or does not meet a 50% participation rate, then the Referendum may be retried up to 3 times.

1. If the first Referendum is accepted and meets a 50% participation rate, then a second Referendum shall be initiated. This referendum should be a Validation Pool that is 1% binding, with a quorum of 1/10 and a win ratio of 2/3.

    1. If the Referendum does not meet quorum, then the Proposal is failed.

    1. If the Referendum is rejected or does not meet a 50% participation rate, then the Referendum may be retried up to 3 times.

1. If the second Referendum is accepted and meets a 50% participation rate, then a third Referendum shall be initiated. This referendum should be a Validation Pool that is 100% binding, with a quorum of 1/10 and a win ratio of 2/3.

    1. If the Referendum does not meet quorum, then the Proposal is failed.

    1. If the Referendum does not meet a 50% participation rate, then the Referendum may be retried up to 3 times.

    1. If the Referendum is rejected, then the Proposal is failed.

1. If the third Referendum is accepted and meets a 50% participation rate, then the Proposal is accepted.

### Judicial

In the Executive governance section we outline how the DAO polices the REP minting process, and the Legislative governance section we outline how the DAO may modify the rules by which it operates. Now, we need to consider that as the DAO develops new rules, it may wish to reevaluate past REP rewards in light of new perspectives.

To achieve such reevaluation, we introduce the Forum reference mechanism. The Forum is a collection of Posts. A Post has a unique ID and one or more authors. A post may also include weighted references to other Posts. Each Validation Pool targets a given Post. When a VP is accepted, the minted REP percolates through the Forum, to the author(s) of the targeted Post, and recursively to the Posts referenced by the targeted Post, the Posts referenced by those Posts, and so on, up to a limit determined by the Reference Chain Limit parameter.

Each reference may be positive or negative. A positive reference "donates" Reputation, while a negative reference "leaches" reputation.

A Post may also reference the Incinerator. Any reputation donated to the Incinerator is burned. A post may not leach reputation from the Incinerator.

#### Forum

- Anyone may add a Post to the Forum

- A Post must have a unique identifier.

    - The Post ID should be a content hash.
    
    - The Post ID should correspond to an off-chain record housing the Post's content.

- A Post must have one or more authors.

    - Each author is identified by their Wallet address.

    - Each author has a weight. Author weights must sum to 100%.

- A Post may include zero or more references.

    - Each reference must include a weight between -1 and 1.

    - Sum of negative weights must be >= -1.

    - Sum of positive weights must be <= 1.

    - A Post may reference the Incinerator with 0 <= weight <= 1.